@@ -946,7 +946,7 @@ class OMFITnstxMHD(SortedDict, OMFITascii):
                 self[line[1]] = {}
             piece = len(self[line[1]])
             # signals.dat
-            if len(line) == 17:
+            if len(line) in [16, 17]:
                 self.type = 'signals'
                 self[line[1]][piece] = dict(
                     zip(
@@ -978,7 +978,7 @@ class OMFITnstxMHD(SortedDict, OMFITascii):
             for group in self:
                 if group not in ['all']:
                     for item in self[group]:
-                        self[group][item]['mds_tree'] = mds_tree_map[self[group][item]['mds_tree']]
+                        self[group][item]['mds_tree'] = mds_tree_map.get(self[group][item]['mds_tree'], self[group][item]['mds_tree'])
             # sort entries according to their `map` fields
             self['mappings'] = {}
             for group in self:
