@@ -96,9 +96,7 @@ class OMFITgenray(OMFITnc):
                 ods[f'core_sources.source.{s}.identifier.index'] = 3  # ECH
             source = ods[f'core_sources.source.{s}.profiles_1d'][time_index]
 
-            source['j_parallel'] = (
-                -1 * np.sign(ods['equilibrium.vacuum_toroidal_field.b0'][time_index]) * self['s_cur_den_onetwo']['data'] / (cm_to_m ** 2)
-            )  # from A/cm^2 to A/m^2
+            source['j_parallel'] = self['s_cur_den_onetwo']['data'] / (cm_to_m ** 2)  # from A/cm^2 to A/m^2
             source['electrons']['energy'] = self['powden_e']['data'] * ergs_to_J / (cm_to_m ** 3)  # from erg/cm^3/s to J/m^3/s
             source['total_ion_energy'] = self['powden_i']['data'] * ergs_to_J / (cm_to_m ** 3)  # from erg/cm^3/s to J/m^3/s
             rho = np.linspace(0, 1, n_rho)
