@@ -18,11 +18,6 @@ from omfit_classes import namelist
 
 from collections import OrderedDict
 
-try:
-    from omfit_plot import *
-except ImportError:
-    warnings.warn('omfit_plot not found: plotting may not work')
-
 __all__ = ['OMFIToedgeInput', 'OMFIToedgeRun', 'OMFIToedgeNC']
 
 
@@ -1073,6 +1068,8 @@ class OMFIToedgeNC(OMFITnc):
         else:
             # use a figure notebook
             # For lists of charge states
+            from omfit_plot import FigureNotebook
+
             fig_notebook = FigureNotebook(nfig=0, name='Contour plots by charge state')
 
             # loop through charge states
@@ -1413,6 +1410,8 @@ class OMFIToedgeNC(OMFITnc):
         # print('rings:',nrings,ring_range,plot_select,axis_type)
 
         # use figure notebook since it supports an unknown number of plots
+        from omfit_plot import FigureNotebook
+
         fig_notebook = FigureNotebook(nfig=0, name='Along Ring Plots')
 
         for ir in ring_range:
